***
* Replication Archive for
* Gerber, Alan S., Eric M. Patashnik, David Doherty, and Conor M. Dowling. 2010. The Public Wants 
* Information, Not Board Mandates, From Comparative Effectiveness Research. Health Affairs 29: 1872-1881.
***
clear 
set mem 500m
cd "SET WORKING DIRECTORY"
//use "health_survey.dta" 
//keep yal011 gender pid3 birthyr educ race income yal001 yal002 yal160 yal161 yal162 yal163 yal164 yal165 yal166 yal180 yal180num yal190* yal181 yal182 yal200 yal201 yal203 yal210 yal211 yal212 yal213 yal214 yal215 yal216 yal217 yal218 yal231 yal232 yal233 yal240 yal120 yal130 yal140 yal170 yal171 yal172 yal190 yal191 yal192 yal193  arg* weight
//save "replication.dta", replace
use "replication.dta", clear

cd tables
set more 1

**********************************
****** CODE DEMOGRAPHICS *********
**********************************
*Turnout
recode yal011 (1 2 3=1) (4=0) (*=.),gen(voted08)
label var voted08 "Turned out in 2008 (1=yes)"

*PID
recode pid3 (1=1) (2=2) (3 4 5=3) (*=.), gen(party3)
tab party3, gen(pid_)
rename pid_1 pid_democrat
rename pid_2 pid_republican
rename pid_3 pid_independent
label var pid_democrat "Democrat"
label var pid_republican "Republican"
label var pid_independent "Independent"

*Age
gen age=2010-birthyr
label var age "Age (in years)"
recode age (18/37=1) (38/51=2) (52/64=3) (65/98=4), gen(age4)
label var age4 "Age (4-categories)"
tab age4, gen(ageD)
drop ageD1
label var ageD2 "Age: 38-51"
label var ageD3 "Age: 52-64"
label var ageD4 "Age: 65+"

*Education
label var educ "Education (1 no HS; 6 postgrad)"
recode educ (1 2=1) (3 4=2) (5 6=3) (*=.), gen(educ3)
label var educ3 "Education (3-categories)"
tab educ3, gen (educD)
drop educD1
label var educD2 "Education: Some College (Medium)"
label var educD3 "Education: 4-year College + (High)"

*Race
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White"
label var r_black "Black"
label var r_hispanic "Hispanic"
label var r_other "Other Race"

*Gender
recode gender (1=0) (2=1), gen(female)
label var female "Female=1"

*Income
recode income (1/5=1) (6/8=2) (9/14=3) (15=4), gen(income3)
tab income3, gen(incomeD)
drop incomeD1
label var incomeD2 "Income: $30-60k (Medium)"
label var incomeD3 "Income: >$60k (High)"
label var incomeD4 "Income Missing"
label var income "Family Income (1=<$10k; 14=>$150k)"

*** RECODE ALL SKIPPED TO MISSING ***
recode yal001 yal002 yal160 yal161 yal162 yal163 yal164 yal165 yal166 yal180 yal181 yal182 yal200 yal201 yal203 yal210 yal211 yal212 yal213 yal214 yal215 yal216 yal217 yal218 yal231 yal232 yal233 yal240 (1=1) (2=2) (3=3) (4=4) (5=5) (9=9) (*=.)

foreach i in yal120 yal130 yal140 yal170 yal171 yal172 yal190 yal191 yal192 yal193 {
replace `i'=. if `i'>100
}

*** EXPERIMENT VARIABLES ***
* Pain/Life treatment
label var yal180num "Pain = 1; Life = 0"

* Board experiment indicators/measures
recode yal190anum (0=1) (1=0) (*=.), gen(board_citizens)
recode yal190bnum (0=1) (1=0) (*=.), gen(board_insurance)
recode yal190cnum (0=1) (1=0) (*=.), gen(board_device)
recode yal190dnum (0=1) (1=0) (*=.), gen(board_gov)
label var board_citizens "Citizens = 1"
label var board_insurance "Insurance Cos. = 1"
label var board_device "Device Manufacturers = 1"
label var board_gov "Government Officials = 1"

label var yal190 "Board: Establish Voluntary Guidelines"
label var yal191 "Board: Establish Mandatory Guidelines"
label var yal192 "Board: Trust Make Good Decisions"
label var yal193 "Board: Trust Make Fair Decisions"

gen number_on_board=board_citizens+board_insurance+board_device+board_gov 
label var number_on_board "Number of Groups on Board (0-4)

*drop 11 cases prior to wording change
tab arg2pro, gen(drop_old_wording_cases)
drop if drop_old_wording_cases3==1
drop drop_old_wording_cases*

*generate experimental condition variables for mlogits to test balance
gen conditions1 = arg1pronum+ (arg1negnum+1)*10
gen conditions2 = arg2pronum+ (arg2negnum+1)*10
gen boardconditions=board_citizens+(board_insurance+1)*10+(board_device+1)*100+(board_gov+1)*1000
tab boardconditions, gen(sig_boardcond_)

* Countervailing messages
tab conditions1, gen(sig_cond1_)
label var sig_cond1_1 "Pro=Improve outcomes ; Con=One-size-fits-all"
label var sig_cond1_2 "Pro=Reduce deficit ; Con=One-size-fits-all"
label var sig_cond1_3 "Pro=Improve outcomes ; Con=Ration care"
label var sig_cond1_4 "Pro=Reduce deficit ; Con=Ration care"
label var sig_cond1_5 "Pro=Improve outcomes ; Con=Waste taxpayer money"
label var sig_cond1_6 "Pro=Reduce deficit ; Con=Reduce innovation"

tab conditions2, gen(sig_cond2_)
label var sig_cond2_1 "Con=One-size-fits-all; Pro=Give doctors information" 
label var sig_cond2_2 "Con=One-size-fits-all; Pro=Doctors want it" 
label var sig_cond2_3 "Con=One-size-fits-all; Pro=Doctors have input"
label var sig_cond2_4 "Con=Ration care; Pro=Deficits/best allocation"
label var sig_cond2_5 "Con=Ration care; Pro=Scare tactic"
label var sig_cond2_6 "Con=Ration care; Pro=Cut costs/not quality" 


*******************************
***** OUTCOME VARIABLES *******
*******************************
label var yal120 "Initial Support for CER (0-100)"

gen change_support=yal130-yal120
label var change_support "Change in Support for CER (-100 to 100)"

** Translating CER to Policy Indices
gen cer_trans_info=(yal160+yal162)/2 
gen cer_trans_coverage=(yal163+yal164)/2
gen cer_trans_allocation=(yal161+yal166)/2
gen cer_trans_copay=yal165
label var cer_trans_info "Support CER to provide consumer information"
label var cer_trans_coverage "Support CER to make coverage decisions"
label var cer_trans_allocation "Support CER to allocate government resources"
label var cer_trans_copay "Support CER to raise charges or copayments"


*** DICHOTOMIZE TO GENERATE SUBGROUP MARGINALS ***
foreach i in yal001 yal002 yal160 yal161 yal162 yal163 yal164 yal165 yal166 {
tab `i', gen(dich_`i'_)
gen dich_`i'_1_2=dich_`i'_1+dich_`i'_2
gen dich_`i'_4_5=dich_`i'_4+dich_`i'_5
local vlabel : variable label `i'
label var dich_`i'_1_2 "`vlabel' (1 or 2)"
label var dich_`i'_4_5 "`vlabel' (4 or 5)"
}

***DEFINE SAMPLE
reg yal120 yal001 yal002 yal130 yal140 yal160 yal161 yal162 yal163 yal164 yal165 yal166 yal180 yal181 yal182 yal190 yal191 yal192 yal193 voted08 pid_democrat pid_republican ageD* educD* r_black r_hispanic r_other gender incomeD* 
gen insample=e(sample)
drop if insample!=1

**** SUMMARY STATS ****
outsum female r_white r_black r_hispanic r_other age educ incomeD4 voted08 pid_democrat pid_independent pid_republican if insample==1 [aw=weight] using "A1_summary.out", bracket replace
//average income among those providing non-missing/refusal responses
outsum income if insample==1 & incomeD4!=1 [aw=weight] using "A1_summary", bracket append


***************************************************
****** NOTE ON SIMILARITIES TO OTHER SAMPLES ******
***************************************************
foreach i in yal200 yal203 yal240 {
tab `i' if insample==1 [aw=weight]
}

***************************************************
****** EXHIBIT 1 - SUPPORT CER BY SUBGROUP ********
****** Table 6.1 in UNHEALTHY POLITICS     ********
***************************************************
foreach i in yal120 {
qui ci mean `i' if insample==1 [aw=weight]
matrix means=r(mean)

forvalues p=0/1{
qui ci mean `i' if voted08==`p' & insample==1 [aw=weight] 
matrix means=means\r(mean)
}
forvalues p=1/3{
qui ci mean `i' if party3==`p' & insample==1 [aw=weight]
matrix means=means\r(mean)
}
forvalues p=1/3{
qui ci mean `i' if party3==`p' & insample==1 & voted08==1 [aw=weight]
matrix means=means\r(mean)
}
forvalues p=1/3{
qui ci mean `i' if party3==`p' & insample==1 & voted08==0 [aw=weight]
matrix means=means\r(mean)
}
forvalues p=1/4{
qui ci mean `i' if age4==`p' & insample==1 [aw=weight]
matrix means=means\r(mean)
}
forvalues p=1/3{
qui ci mean `i' if educ3==`p' & insample==1 [aw=weight]
matrix means=means\r(mean)
}
foreach p in white black hispanic{
qui ci mean `i' if r_`p'==1 & insample==1 [aw=weight]
matrix means=means\r(mean)
}
forvalues p=1/3{
qui ci mean `i' if income3==`p' & insample==1 [aw=weight]
matrix means=means\r(mean)
}
forvalues p=0/1{
qui ci mean `i' if female==`p' & insample==1 [aw=weight] 
matrix means=means\r(mean)
}
}
*** OUTPUT MEANS ***
svmat means, names(full)
//top three rows are means for full sample, voters, and non-voters
outsheet full* using exhibit1.csv,comma replace
drop full*

//reg yal120 voted08 if insample==1 [aw=weight], r
//matrix pvalues=-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 pid_democrat pid_republican if insample==1 [aw=weight], r
matrix pvalues=-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 pid_democrat pid_republican if voted08==1 & insample==1 [aw=weight], r
matrix pvalues=pvalues\-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 pid_democrat pid_republican if voted08==0 & insample==1 [aw=weight], r
matrix pvalues=pvalues\-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 ageD2 ageD3 ageD4 if insample==1 [aw=weight], r
matrix pvalues=pvalues\-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 educD2 educD3 if insample==1 [aw=weight], r
matrix pvalues=pvalues\-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 r_black r_hispanic if insample==1 & r_other==0 [aw=weight], r
matrix pvalues=pvalues\-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 incomeD2 incomeD3 incomeD4 if insample==1 [aw=weight], r
matrix pvalues=pvalues\-(Ftail(e(df_m),e(df_r),e(F)))
reg yal120 female if insample==1 [aw=weight], r
matrix pvalues=pvalues\-(Ftail(e(df_m),e(df_r),e(F)))

*** OUTPUT P-VALUES FOR SUBGROUP DIFFERENCES ***
svmat pvalues, names(full)
outsheet full* using exhibit1_pvalues.csv,comma replace
drop full*

reg yal120 voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight], r
test pid_democrat pid_republican
local sig_pid=r(p)
test ageD2 ageD3 ageD4 
local sig_age=r(p)
test educD2 educD3 
local sig_educ=r(p)
test r_black r_hispanic r_other 
local sig_race=r(p)
outreg2 using "A2_regressions.out", label se bracket addstat("Joint significance: Party ID",`sig_pid',"Joint significance: Education",`sig_educ',"Joint significance: Age",`sig_age',"Joint significance: Race",`sig_race') tdec(3) replace 

************************************************************
***** EXHIBITS 2 and 3 - TRANSLATING CER TO POLICY *********
****** Exhibit 2 ==> Figure 3.4 in UNHEALTHY POLITICS ******
************************************************************
foreach i in yal160 yal162 yal163 yal164 yal161 yal166 yal165 {

qui ci mean dich_`i'_1_2 if insample==1 [aw=weight]
matrix means_`i'=r(mean)
qui ci mean dich_`i'_4_5 if insample==1 [aw=weight]
matrix means_`i'=means_`i',r(mean)

if "`i'"=="yal160"{
matrix means_full=means_`i'
}
else{
matrix means_full=means_full\means_`i'
}
}
matrix output_full=means_full

*** OUTPUT MEANS FOR EXHIBIT 2 / Figure 3.4 of Unhealthy Politics***
svmat output_full, names(full)
outsheet full* using exhibit2_data.csv,comma replace
drop full*

foreach i in cer_trans_info cer_trans_coverage cer_trans_allocation cer_trans_copay{
reg `i' voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight], r
test pid_democrat pid_republican
local sig_pid=r(p)
test ageD2 ageD3 ageD4 
local sig_age=r(p)
test educD2 educD3 
local sig_educ=r(p)
test r_black r_hispanic r_other 
local sig_race=r(p)
outreg2 using "A2_regressions.out", label se bracket addstat("Joint significance: Party ID",`sig_pid',"Joint significance: Education",`sig_educ',"Joint significance: Age",`sig_age',"Joint significance: Race",`sig_race') tdec(3) append


include "..\subgroupsmarginals_mean.do"

if "`i'"=="cer_trans_info"{
matrix means_full=means
matrix pvalues_full=pvalues

}
else{
matrix means_full=means_full\means
matrix pvalues_full=pvalues_full\pvalues

}
}

matrix output_full=means_full

*** OUTPUT MEANS ***
svmat output_full, names(full)
outsheet full* using exhibit3.csv,comma replace
drop full*

*** OUTPUT P-VALUES FOR SUBGROUP DIFFERENCES ***
svmat pvalues_full, names(full)
outsheet full* using exhibit3_pvalues.csv,comma replace
drop full*

** Check pairwise claims about PID and Race differences
foreach i in cer_trans_info cer_trans_coverage cer_trans_allocation cer_trans_copay{
reg `i' pid_democrat pid_republican if insample==1 [aw=weight], r
reg `i' r_white if insample==1 & r_other==0 [aw=weight], r
}


******** NOTE ON GENDER DIFFERENCES ABOUT HOW MUCH MEDICINE IS EVIDENCE BASED ***********
foreach i in dich_yal162_4_5 dich_yal001_1_2 dich_yal002_1_2{
tab `i' female if insample==1 [aw=weight], col
reg `i' voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight], r
}

***********************************************************
***** BOARD COMPOSITION SECTION (NO EXHIBIT) **************
***********************************************************
foreach i in yal190 yal191 yal192 yal193 {
reg `i' board_citizens board_insurance board_device board_gov voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight], r
test pid_democrat pid_republican
local sig_pid=r(p)
test ageD2 ageD3 ageD4 
local sig_age=r(p)
test educD2 educD3 
local sig_educ=r(p)
test r_black r_hispanic r_other 
local sig_race=r(p)
if "`i'"=="yal190"{
outreg2 using "A4_board_regressions.out", label se bracket addstat("Joint significance: Party ID",`sig_pid',"Joint significance: Education",`sig_educ',"Joint significance: Age",`sig_age',"Joint significance: Race",`sig_race') tdec(3) replace 
}
else{
outreg2 using "A4_board_regressions.out", label se bracket addstat("Joint significance: Party ID",`sig_pid',"Joint significance: Education",`sig_educ',"Joint significance: Age",`sig_age',"Joint significance: Race",`sig_race') tdec(3) append
}

include "..\subgroupsmarginals_mean.do"

if "`i'"=="yal190"{
matrix means_full=means
matrix pvalues_full=pvalues
}
else{
matrix means_full=means_full\means
matrix pvalues_full=pvalues_full\pvalues
}
}

*** OUTPUT MEANS ***
svmat means_full, names(full)
outsheet full* using A3_board_appendix.csv,comma replace
drop full*

*** OUTPUT P-VALUES FOR SUBGROUP DIFFERENCES ***
svmat pvalues_full, names(full)
outsheet full* using A3_board_appendix_pvalues.csv,comma replace
drop full*

* text about party ID by turnout
foreach i in yal190 yal191 yal192 yal193 {
table pid3 if insample==1 & voted08==0 [aw=weight], c(mean `i')
table pid3 if insample==1 & voted08==1 [aw=weight], c(mean `i')
}

*correlation between good and fair
corr yal192 yal193 if insample==1 [aw=weight]

* Check balance
mlogit boardconditions voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight]

** CHECK BALANCE
logit yal180num voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [pw=weight]


******** NOTE ON REBATES V. HIGHER COPAY ITEMS **************
foreach i in yal170 yal171 yal172 {
sum `i' if insample==1 [aw=weight]
}


************************************************
*** NEW EXPERIMENT DATA                      ***
*** Tables 3.1 and 3.2 in UNHEALTHY POLITICS ***
************************************************
set mem 500m

//use "..\health_experiment_rerun.dta", clear
//keep yal011 gender pid3 birthyr educ race income yal130* yal120 yal140 arg* weight
//save "..\replication_experiment.dta", replace
use "..\replication_experiment.dta", clear
set more 1

**********************************
****** CODE DEMOGRAPHICS *********
**********************************
*Turnout
recode yal011 (1 2 3=1) (4=0) (*=.),gen(voted08)
label var voted08 "Turned out in 2008 (1=yes)"

*PID
recode pid3 (1=1) (2=2) (3 4 5=3) (*=.), gen(party3)
tab party3, gen(pid_)
rename pid_1 pid_democrat
rename pid_2 pid_republican
rename pid_3 pid_independent
label var pid_democrat "Democrat"
label var pid_republican "Republican"
label var pid_independent "Independent"

*Age
gen age=2010-birthyr
label var age "Age (in years)"
recode age (18/37=1) (38/51=2) (52/64=3) (65/98=4), gen(age4)
label var age4 "Age (4-categories)"
tab age4, gen(ageD)
drop ageD1
label var ageD2 "Age: 38-51"
label var ageD3 "Age: 52-64"
label var ageD4 "Age: 65+"

*Education
label var educ "Education (1 no HS; 6 postgrad)"
recode educ (1 2=1) (3 4=2) (5 6=3) (*=.), gen(educ3)
label var educ3 "Education (3-categories)"
tab educ3, gen (educD)
drop educD1
label var educD2 "Education: Some College (Medium)"
label var educD3 "Education: 4-year College + (High)"

*Race
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White"
label var r_black "Black"
label var r_hispanic "Hispanic"
label var r_other "Other Race"

*Gender
recode gender (1=0) (2=1), gen(female)
label var female "Female=1"

*Income
recode income (1/5=1) (6/8=2) (9/14=3) (15=4), gen(income3)
tab income3, gen(incomeD)
drop incomeD1
label var incomeD2 "Income: $30-60k (Medium)"
label var incomeD3 "Income: >$60k (High)"
label var incomeD4 "Income Missing"
label var income "Family Income (1=<$10k; 14=>$150k)"

* order of pro/con arguments indicator
gen yal130_order=(yal130==999)
label var yal130_order "Con First"
replace yal130=yal130b if yal130_order==1

* replace any skipped/RF with missing (there aren't any)
foreach i in yal120 yal130 yal140 {
replace `i'=. if `i'>100
}

* generate change in support variable
gen change_support=yal130-yal120

* generate indicators for pro and con argument assignments
tab arg1neg, gen(negarg_130_)
tab arg1pro, gen(posarg_130_)

label var negarg_130_1 "Innovation"
label var negarg_130_2 "Waste of money"
label var negarg_130_3 "Ration"
label var negarg_130_4 "One-size"

label var posarg_130_1 "Deficit"
label var posarg_130_2 "Better Outcomes"

* generate indicators in the order listed in the Exhibits (down first column, then down second column)
gen yal130_cond1=(posarg_130_2==1) & (negarg_130_4==1)
gen yal130_cond2=(posarg_130_2==1) & (negarg_130_3==1)
gen yal130_cond3=(posarg_130_2==1) & (negarg_130_2==1)

gen yal130_cond4=(posarg_130_1==1) & (negarg_130_4==1)
gen yal130_cond5=(posarg_130_1==1) & (negarg_130_3==1)
gen yal130_cond6=(posarg_130_1==1) & (negarg_130_1==1)


* generate indicators for pro and con argument assignments
tab arg2neg, gen(negarg_140_)
tab arg2pro, gen(posarg_140_)

label var negarg_140_1 "Ration"
label var negarg_140_2 "One-size"

label var posarg_140_1 "Best allocation"
label var posarg_140_2 "Patients are similar"
label var posarg_140_3 "Doctors want it"
label var posarg_140_4 "Medical studies can ID heterogeneity"
label var posarg_140_5 "Scare tactic (one size)"
label var posarg_140_6 "Scare tactic (rationing)"
label var posarg_140_7 "Cut costs, not quality"

* generate indicators in the order listed in the Exhibits (down first column, then down second column)
gen yal140_cond1=posarg_140_3
gen yal140_cond2=posarg_140_5
gen yal140_cond3=posarg_140_2
gen yal140_cond4=posarg_140_4
gen yal140_cond5=posarg_140_1
gen yal140_cond6=posarg_140_6
gen yal140_cond7=posarg_140_7


* gen assignment variables to test balance
gen conditions1=negarg_130_1+(2*negarg_130_2)+(4*negarg_130_3)+(8*negarg_130_4)+(16*posarg_130_1)+(32*posarg_130_2)
gen conditions2=posarg_140_1+(2*posarg_140_2)+(4*posarg_140_3)+(8*posarg_140_4)+(16*posarg_140_5)+(32*posarg_140_6)+(64*posarg_140_7)

*** set sample (we don't have any missing)
reg yal120 yal130 yal140 voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female [aw=weight], r
gen insample=e(sample)

**** SUMMARY STATS ****
outsum female r_white r_black r_hispanic r_other age educ incomeD4 voted08 pid_democrat pid_independent pid_republican if insample==1 [aw=weight] using "A1_summary", bracket append
outsum income if insample==1 & incomeD4!=1 [aw=weight] using "A1_summary", bracket append

*test balance
mlogit conditions1 voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight]
foreach i in pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female {
test [17]`i' [20]`i' [24]`i' [34]`i' [40]`i'
}
mlogit conditions2 voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight]
foreach i in pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female {
test [2]`i' [4]`i' [8]`i' [16]`i' [32]`i'
}

* change in support regression 
reg change_support yal130_cond1-yal130_cond5 voted08 pid_democrat pid_republican ageD2 ageD3 ageD4 educD2 educD3 r_black r_hispanic r_other incomeD2 incomeD3 incomeD4 female if insample==1 [aw=weight], r


* generate matrix of values (means, Ns) for Exhibit 4
sum change_support if yal130_cond1==1 & insample==1 [aw=weight]
matrix experiment1_1=r(mean)\-r(N)
sum change_support if yal130_cond2==1 & insample==1 [aw=weight]
matrix experiment1_2=r(mean)\-r(N)
sum change_support if yal130_cond3==1 & insample==1 [aw=weight]
matrix experiment1_3=r(mean)\-r(N)
sum change_support if yal130_cond4==1 & insample==1 [aw=weight]
matrix experiment1_4=r(mean)\-r(N)
sum change_support if yal130_cond5==1 & insample==1 [aw=weight]
matrix experiment1_5=r(mean)\-r(N)
sum change_support if yal130_cond6==1 & insample==1 [aw=weight]
matrix experiment1_6=r(mean)\-r(N)
matrix experiment1_null=.\.
matrix experiment1_A=experiment1_1,experiment1_4
matrix experiment1_B=experiment1_2,experiment1_5
matrix experiment1_C=experiment1_3,experiment1_null
matrix experiment1_D=experiment1_null,experiment1_6
matrix experiment1=experiment1_A\experiment1_B\experiment1_C\experiment1_D
matrix list experiment1
svmat experiment1, names(full)
outsheet full* using A5_neteffects.csv,comma replace
drop full*

* change in support significant (i.e., different from 0; by condition)
forvalues i=1/6{
reg change_support if yal130_cond`i'==1 [aw=weight]
}

* generate matrix of values (means, Ns) for Exhibit 5
sum yal140 if yal140_cond1==1 & insample==1 [aw=weight]
matrix experiment1_1=r(mean)\-r(N)
sum yal140 if yal140_cond2==1 & insample==1 [aw=weight]
matrix experiment1_2=r(mean)\-r(N)
sum yal140 if yal140_cond3==1 & insample==1 [aw=weight]
matrix experiment1_3=r(mean)\-r(N)
sum yal140 if yal140_cond4==1 & insample==1 [aw=weight]
matrix experiment1_4=r(mean)\-r(N)
sum yal140 if yal140_cond5==1 & insample==1 [aw=weight]
matrix experiment1_5=r(mean)\-r(N)
sum yal140 if yal140_cond6==1 & insample==1 [aw=weight]
matrix experiment1_6=r(mean)\-r(N)
sum yal140 if yal140_cond7==1 & insample==1 [aw=weight]
matrix experiment1_7=r(mean)\-r(N)
matrix experiment1_null=.\.
matrix experiment1=experiment1_1,experiment1_null\experiment1_2,experiment1_null\experiment1_3,experiment1_null\experiment1_4,experiment1_null\experiment1_null,experiment1_5\experiment1_null,experiment1_6\experiment1_null,experiment1_7
matrix list experiment1
svmat experiment1, names(full)
outsheet full* using A6_rebuttals.csv,comma replace
drop full*


* center persuasion rating at 50 so can test whether mean differs from 50 in regression framework (using weights)
gen centered140=yal140-50
forvalues i=1/7{
reg centered140 if yal140_cond`i'==1 [aw=weight]
}

